pub struct RenderTextWidget { /* private fields */ }Trait Implementations
Sourceimpl Debug for RenderTextWidget
impl Debug for RenderTextWidget
Sourceimpl Widget for RenderTextWidget
impl Widget for RenderTextWidget
Sourcetype Props<'a> = RenderText
type Props<'a> = RenderText
The props that this widget needs to be created or updated. Props define
all of the values that a widget’s user can specify every render.
Sourcetype Response = ()
type Response = ()
The type that the widget will return to the user when it is created or
updated. This type should contain information like whether the widget
was clicked, had keyboard input, or other info that might be useful.
Sourcefn update(&mut self, props: Self::Props<'_>) -> Self::Response
fn update(&mut self, props: Self::Props<'_>) -> Self::Response
Update the widget with new props.
Sourcefn layout(&self, ctx: LayoutContext<'_>, input: Constraints) -> Vec2
fn layout(&self, ctx: LayoutContext<'_>, input: Constraints) -> Vec2
Calculate this widget’s layout with the given constraints and return its
size. The returned size must fit within the given constraints, which can
be done using
constraints.constrain(size). Read moreSourcefn paint(&self, ctx: PaintContext<'_>)
fn paint(&self, ctx: PaintContext<'_>)
Paint the widget based on its current state. Read more
Sourcefn flex(&self) -> (u32, FlexFit)
fn flex(&self) -> (u32, FlexFit)
Returns whether this widget should grow to fill a flexible layout, and
if so, what weight should be applied to it if other widgets also want to
grow. Read more
Sourcefn flow(&self) -> Flow
fn flow(&self) -> Flow
Returns the behavior that this widget should have when part of a layout. Read more
Sourcefn default_layout(
&self,
ctx: LayoutContext<'_>,
constraints: Constraints,
) -> Vec2
fn default_layout( &self, ctx: LayoutContext<'_>, constraints: Constraints, ) -> Vec2
A convenience method that always performs the default layout strategy
for a widget. This method is intended to be called from custom widget’s
layout methods.Sourcefn default_paint(&self, ctx: PaintContext<'_>)
fn default_paint(&self, ctx: PaintContext<'_>)
A convenience method that always performs the default painting operation
for a widget. This method is intended to be called from custom widget’s
paint methods.Sourcefn event_interest(&self) -> EventInterest
fn event_interest(&self) -> EventInterest
Tells which events the widget is interested in receiving. Read more
Sourcefn event(&mut self, ctx: EventContext<'_>, event: &WidgetEvent) -> EventResponse
fn event(&mut self, ctx: EventContext<'_>, event: &WidgetEvent) -> EventResponse
Handle the given event and update the widget’s state. Read more
Tell which widget should be navigated to if the user navigates in a
given direction.