Stack

Struct Stack 

#[non_exhaustive]
pub struct Stack {}
A Stack widget. This widget does nothing interesting on its own, but when used “inside” other layouts, such as List, it will stacks its own children, rather than following the layout of its own parent. This internal layouting is just using yakui’s default layout algorithm.

Responds with StackResponse.

Shorthand:

yakui::column(|| {
    yakui::label("on top");
    yakui::stack(|| {
        // this would compose, by being stacked,
        // to appear like "hello world", barring issues from spacing,
        // as opposed to continuing the columnar layout setup above.
        yakui::text(12.0, "hello");
        yakui::text(12.0, "      world");
    });
    yakui::label("on bottom");
});

Implementations

Source

impl Stack

pub fn new() -> Self

Creates a new Stack.

pub fn show<F: FnOnce()>(self, children: F) -> Response<StackResponse>

Shows the Stack along with its children.